cern_ch_test_data = {
    'geturl': 'http://home.web.cern.ch/',
    'content':
    '<!DOCTYPE html>\n<!--[if IEMobile 7]><html class="iem7"  lang="en" dir="ltr"><![endif]-->\n<!--[if lte '
    'IE 6]><html class="ie6 ie6-7 ie6-8"  lang="en" dir="ltr"><![endif]-->\n<!--[if (IE 7)&(!IEMobile)]><htm'
    'l class="ie7 ie6-7 ie6-8"  lang="en" dir="ltr"><![endif]-->\n<!--[if IE 8]><html class="ie8 ie6-8"  lan'
    'g="en" dir="ltr"><![endif]-->\n<!--[if (gte IE 9)|(gt IEMobile 7)]><!--><html  lang="en" dir="ltr"\n  x'
    'mlns:content="http://purl.org/rss/1.0/modules/content/"\n  xmlns:dc="http://purl.org/dc/terms/"\n  xmln'
    's:foaf="http://xmlns.com/foaf/0.1/"\n  xmlns:og="http://ogp.me/ns#"\n  xmlns:rdfs="http://www.w3.org/20'
    '00/01/rdf-schema#"\n  xmlns:sioc="http://rdfs.org/sioc/ns#"\n  xmlns:sioct="http://rdfs.org/sioc/types#'
    '"\n  xmlns:skos="http://www.w3.org/2004/02/skos/core#"\n  xmlns:xsd="http://www.w3.org/2001/XMLSchema#"'
    '><!--<![endif]-->\n\n<head profile="http://www.w3.org/1999/xhtml/vocab">\n  <meta http-equiv="Content-T'
    'ype" content="text/html; charset=utf-8" />\n<link rel="shortcut icon" href="http://home.web.cern.ch/sit'
    'es/home.web.cern.ch/themes/cern_public/favicon.ico" type="image/vnd.microsoft.icon" />\n<meta name="des'
    'cription" content="CERN, the European Organization for Nuclear Research, is one of the world\xe2\x80'
    '\x99s largest and most respected centres for scientific research. Its business is fundamental physics, '
    'finding out what the Universe is made of and how it works." />\n<meta name="keywords" content="physics,'
    ' CERN, Large Hadron Collider, LHC, high-energy physics, particles, science" />\n<meta name="generator" '
    'content="Drupal 7 (http://drupal.org)" />\n<link rel="canonical" href="http://home.web.cern.ch/" />\n<l'
    'ink rel="shortlink" href="http://home.web.cern.ch/node/186" />\n  <title>CERN | Accelerating science</t'
    'itle>\n\n  <meta name="MobileOptimized" content="width">\n  <meta name="HandheldFriendly" content="true'
    '">\n  <meta name="apple-mobile-web-app-capable" content="yes">\n  <meta http-equiv="cleartype" content='
    '"on">\n  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">\n\n  <meta name="viewport" cont'
    'ent="width=device-width, initial-scale=1.0, minimum-scale=1.0" />\n\n  <!--[if (lt IE 9) & (!IEMobile)]'
    '>\n    <script src="/sites/home.web.cern.ch/themes/cern_base/js/ie/html5-shiv.js"></script>\n    <scrip'
    't src="/sites/home.web.cern.ch/themes/cern_base/js/ie/respond.min.js"></script>\n  <![endif]-->\n\n  <!'
    '-- Type from Google Fonts -->\n  <!--<link href=\'//fonts.googleapis.com/css?family=PT+Sans:400,400ital'
    'ic,700\' rel=\'stylesheet\' type=\'text/css\' /> -->\n\n  <!-- Type from CERN Framework -->\n  <!--<lin'
    'k href=\'//framework.web.cern.ch/framework/2.0/fonts/PTSansWeb/PTSansWeb.css\' rel=\'stylesheet\' type='
    '\'text/css\' /> -->\n\n  <link type="text/css" rel="stylesheet" href="http://home.web.cern.ch/sites/hom'
    'e.web.cern.ch/files/css/css_ywqYrtSodM0qVMzAkOSnqZ_iBnAVpkSeD_yPtUN9tBk.css" media="all" />\n<link type'
    '="text/css" rel="stylesheet" href="http://home.web.cern.ch/sites/home.web.cern.ch/files/css/css_GqCqCmG'
    'spWzZsDVTgkFoFb2eEt4xaByq4GFNcVi8QG4.css" media="all" />\n<link type="text/css" rel="stylesheet" href="'
    'http://home.web.cern.ch/sites/home.web.cern.ch/files/css/css_9XLd-eqHVqBRSjAe9YzfIoy5u3JuaFAqxPoLDXUg9e'
    'w.css" media="all" />\n<link type="text/css" rel="stylesheet" href="http://home.web.cern.ch/sites/home.'
    'web.cern.ch/files/css/css_jF0Zbf-OleWOug30HRVzE2aiN5qhdf1wXZteyandyzc.css" media="all" />\n<link type="'
    'text/css" rel="stylesheet" href="http://framework.web.cern.ch/framework/2.0/fonts/PTSansWeb/PTSansWeb.c'
    'ss" media="all" />\n<link type="text/css" rel="stylesheet" href="http://home.web.cern.ch/sites/home.web'
    '.cern.ch/files/css/css_SMGsWsGty_Sl5dmMxMHCnhpUk6m4iKH-GIs4zvK0oVY.css" media="all" />\n<link type="tex'
    't/css" rel="stylesheet" href="http://home.web.cern.ch/sites/home.web.cern.ch/files/css/css__7Hj34xYiUtx'
    'OrhD0rkrYUCCxpeg6nkDYfziLiHOghM.css" media="all" />\n<link type="text/css" rel="stylesheet" href="http:'
    '//home.web.cern.ch/sites/home.web.cern.ch/files/css/css_e0Oi8I1L8cGJ7KxcUbimLkO-ivlPDoZXuBZMWKAz5GY.css'
    '" media="print" />\n\n<!--[if lt IE 8]>\n<link type="text/css" rel="stylesheet" href="http://home.web.c'
    'ern.ch/sites/home.web.cern.ch/files/css/css_IJ5Z0j6pyxnr4TEmO0hiXWrh8FMpT6aq_hWn1LpRNOY.css" media="all'
    '" />\n<![endif]-->\n  <script type="text/javascript" src="http://home.web.cern.ch/sites/home.web.cern.c'
    'h/files/js/js_xAPl0qIk9eowy_iS9tNkCWXLUVoat94SQT48UBCFkyQ.js"></script>\n<script type="text/javascript"'
    ' src="http://home.web.cern.ch/sites/home.web.cern.ch/files/js/js_Ohtm-rFJ0XNT-5s2mWFHGwo0EWpCsHX-v1Itjh'
    'VrGoY.js"></script>\n<script type="text/javascript" src="http://home.web.cern.ch/sites/home.web.cern.ch'
    '/files/js/js_NpX2cwCeepkWZZ194B6-ViyVBHleaYLOx5R9EWBOMRU.js"></script>\n<script type="text/javascript" '
    'src="http://home.web.cern.ch/sites/home.web.cern.ch/files/js/js_BWYblUOX1rj6s8SKnU5DoiFsIeLjtH3qG0Dwpb9'
    'jBSc.js"></script>\n<script type="text/javascript" src="http://home.web.cern.ch/sites/home.web.cern.ch/'
    'modules/lightbox2/js/lightbox.js?1436794829"></script>\n<script type="text/javascript" src="http://home'
    '.web.cern.ch/sites/home.web.cern.ch/files/js/js_Tpg_7vBp-NVtNabkVUB3KrJqOsCb3zJDvwZEpjw2xEo.js"></scrip'
    't>\n<script type="text/javascript">\n<!--//--><![CDATA[//><!--\n(function(i,s,o,g,r,a,m){i["GoogleAnaly'
    'ticsObject"]=r;i[r]=i[r]||function(){(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.creat'
    'eElement(o),m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)})(window,do'
    'cument,"script","//www.google-analytics.com/analytics.js","ga");ga("create", "UA-8058079-23", {"cookieD'
    'omain":"auto"});ga("send", "pageview");\n//--><!]]>\n</script>\n<script type="text/javascript" src="htt'
    'p://home.web.cern.ch/sites/home.web.cern.ch/files/js/js_ck0sm0C-L4_vjW_eqGFO_BWEFc3ACqnJu4Q91NgpEL8.js"'
    '></script>\n<script type="text/javascript" src="http://home.web.cern.ch/sites/home.web.cern.ch/files/js'
    '/js_SoM4yXNp1Q-39XQdlNtUDZ98JaZ1XADfPwmikvdHd2c.js"></script>\n<script type="text/javascript">\n<!--//-'
    '-><![CDATA[//><!--\njQuery.extend(Drupal.settings, {"basePath":"\\/","pathPrefix":"","ajaxPageState":{"'
    'theme":"cern_public","theme_token":"LXCMCii84gm5XckxAkSPcnc7uw3XOdF2gcWvxoZj2eY","js":{"misc\\/jquery.j'
    's":1,"misc\\/jquery.once.js":1,"misc\\/drupal.js":1,"misc\\/ui\\/jquery.ui.core.min.js":1,"misc\\/ui\\/'
    'jquery.ui.widget.min.js":1,"misc\\/ui\\/jquery.ui.button.min.js":1,"misc\\/ui\\/jquery.ui.mouse.min.js"'
    ':1,"misc\\/ui\\/jquery.ui.draggable.min.js":1,"misc\\/ui\\/jquery.ui.position.min.js":1,"misc\\/ui\\/jq'
    'uery.ui.resizable.min.js":1,"misc\\/ui\\/jquery.ui.dialog.min.js":1,"sites\\/all\\/modules\\/views\\/js'
    '\\/jquery.ui.dialog.patch.js":1,"misc\\/ajax.js":1,"sites\\/all\\/modules\\/extlink\\/extlink.js":1,"si'
    'tes\\/home.web.cern.ch\\/modules\\/linkit\\/js\\/linkit.js":1,"sites\\/home.web.cern.ch\\/modules\\/lig'
    'htbox2\\/js\\/lightbox.js":1,"sites\\/home.web.cern.ch\\/modules\\/custom_search\\/js\\/custom_search.j'
    's":1,"misc\\/progress.js":1,"sites\\/home.web.cern.ch\\/modules\\/linkit\\/editors\\/ckeditor\\/linkitD'
    'ialog.js":1,"sites\\/all\\/modules\\/google_analytics\\/googleanalytics.js":1,"0":1,"sites\\/home.web.c'
    'ern.ch\\/themes\\/cern_base\\/js\\/cern.js":1,"sites\\/home.web.cern.ch\\/themes\\/cern_public\\/js\\/s'
    'cript.js":1,"sites\\/home.web.cern.ch\\/themes\\/cern_public\\/js\\/cern.home.js":1},"css":{"modules\\/'
    'system\\/system.base.css":1,"modules\\/system\\/system.menus.css":1,"modules\\/system\\/system.messages'
    '.css":1,"modules\\/system\\/system.theme.css":1,"misc\\/ui\\/jquery.ui.core.css":1,"misc\\/ui\\/jquery.'
    'ui.theme.css":1,"misc\\/ui\\/jquery.ui.button.css":1,"misc\\/ui\\/jquery.ui.resizable.css":1,"misc\\/ui'
    '\\/jquery.ui.dialog.css":1,"sites\\/home.web.cern.ch\\/modules\\/aggregator\\/aggregator.css":1,"sites'
    '\\/all\\/modules\\/cernsearchbox\\/cernsearch.css":1,"sites\\/home.web.cern.ch\\/modules\\/cern_toolbar'
    '\\/css\\/remove_ext.css":1,"sites\\/all\\/modules\\/date\\/date_api\\/date.css":1,"sites\\/all\\/module'
    's\\/date\\/date_popup\\/themes\\/datepicker.1.7.css":1,"modules\\/field\\/theme\\/field.css":1,"module'
    's\\/node\\/node.css":1,"modules\\/search\\/search.css":1,"modules\\/user\\/user.css":1,"sites\\/all\\/'
    'modules\\/extlink\\/extlink.css":1,"sites\\/all\\/modules\\/views\\/css\\/views.css":1,"sites\\/all\\/'
    'modules\\/ckeditor\\/css\\/ckeditor.css":1,"sites\\/all\\/modules\\/shib_auth\\/shib_auth.css":1,"site'
    's\\/all\\/modules\\/ctools\\/css\\/ctools.css":1,"sites\\/home.web.cern.ch\\/modules\\/lightbox2\\/cs'
    's\\/lightbox.css":1,"modules\\/locale\\/locale.css":1,"sites\\/home.web.cern.ch\\/modules\\/custom_sear'
    'ch\\/custom_search.css":1,"http:\\/\\/framework.web.cern.ch\\/framework\\/2.0\\/fonts\\/PTSansWeb\\/PTS'
    'ansWeb.css":1,"sites\\/home.web.cern.ch\\/modules\\/cern_toolbar\\/css\\/screen.css":1,"sites\\/home.we'
    'b.cern.ch\\/themes\\/cern_base\\/css\\/disable\\/system.menus.css":1,"sites\\/home.web.cern.ch\\/theme'
    's\\/cern_base\\/css\\/disable\\/system.messages.css":1,"sites\\/home.web.cern.ch\\/themes\\/cern_base'
    '\\/css\\/disable\\/advanced-forum.silver_bells.images.css":1,"sites\\/home.web.cern.ch\\/themes\\/cer'
    'n_base\\/css\\/disable\\/advanced-forum.silver_bells.style.css":1,"sites\\/home.web.cern.ch\\/themes\\'
    '/cern_base\\/css\\/base.css":1,"sites\\/home.web.cern.ch\\/themes\\/cern_public\\/css\\/public.css":1,'
    '"sites\\/home.web.cern.ch\\/themes\\/cern_public\\/css\\/print.css":1,"sites\\/home.web.cern.ch\\/modu'
    'les\\/cern_toolbar\\/css\\/ie.css":1}},"lightbox2":{"rtl":"0","file_path":"\\/(\\\\w\\\\w\\/)public:\\'
    '/","default_image":"\\/sites\\/home.web.cern.ch\\/modules\\/lightbox2\\/images\\/brokenimage.jpg","bor'
    'der_size":10,"font_color":"000","box_color":"fff","top_position":"","overlay_opacity":"0.8","overlay_c'
    'olor":"000","disable_close_click":1,"resize_sequence":0,"resize_speed":400,"fade_in_speed":400,"slide_'
    'down_speed":600,"use_alt_layout":0,"disable_resize":0,"disable_zoom":1,"force_show_nav":0,"show_captio'
    'n":1,"loop_items":0,"node_link_text":"View Image Details","node_link_target":0,"image_count":"Image !c'
    'urrent of !total","video_count":"Video !current of !total","page_count":"Page !current of !total","lit'
    'e_press_x_close":"press \\u003Ca href=\\u0022#\\u0022 onclick=\\u0022hideLightbox(); return FALSE;\\u0'
    '022\\u003E\\u003Ckbd\\u003Ex\\u003C\\/kbd\\u003E\\u003C\\/a\\u003E to close","download_link_text":"","'
    'enable_login":false,"enable_contact":false,"keys_close":"c x 27","keys_previous":"p 37","keys_next":"n'
    ' 39","keys_zoom":"z","keys_play_pause":"32","display_image_size":"original","image_node_sizes":"()","t'
    'rigger_lightbox_classes":"","trigger_lightbox_group_classes":"","trigger_slideshow_classes":"","trigge'
    'r_lightframe_classes":"","trigger_lightframe_group_classes":"","custom_class_handler":0,"custom_trigge'
    'r_classes":"","disable_for_gallery_lists":true,"disable_for_acidfree_gallery_lists":true,"enable_acidf'
    'ree_videos":true,"slideshow_interval":5000,"slideshow_automatic_start":true,"slideshow_automatic_exit"'
    ':true,"show_play_pause":true,"pause_on_next_click":false,"pause_on_previous_click":true,"loop_slides":'
    'false,"iframe_width":600,"iframe_height":400,"iframe_border":1,"enable_video":0},"custom_search":{"for'
    'm_target":"_self","solr":0},"linkit":{"autocompletePath":"http:\\/\\/home.web.cern.ch\\/linkit\\/autoc'
    'omplete\\/___profile___?s=","dashboardPath":"\\/linkit\\/dashboard\\/","currentInstance":{}},"extlink"'
    ':{"extTarget":0,"extClass":"ext","extLabel":"(link is external)","extImgClass":0,"extSubdomains":1,"ex'
    'tExclude":"^Colllide@CERN$|(cern.service-now\\\\.com)","extInclude":"","extCssExclude":"","extCssExpli'
    'cit":"","extAlert":0,"extAlertText":"This link will take you to an external web site. We are not respo'
    'nsible for their content.","mailtoClass":"mailto","mailtoLabel":"(link sends e-mail)"},"googleanalytic'
    's":{"trackOutbound":1,"trackMailto":1,"trackDownload":1,"trackDownloadExtensions":"7z|aac|arc|arj|asf|'
    'asx|avi|bin|csv|doc(x|m)?|dot(x|m)?|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|ms'
    'p|pdf|phps|png|ppt(x|m)?|pot(x|m)?|pps(x|m)?|ppam|sld(x|m)?|thmx|qtm?|ra(m|r)?|sea|sit|tar|tgz|torrent'
    '|txt|wav|wma|wmv|wpd|xls(x|m|b)?|xlt(x|m)|xlam|xml|z|zip"},"cern_public":{"language":"en","path":"site'
    's\\/home.web.cern.ch\\/themes\\/cern_public"}});\n//--><!]]>\n</script>\n\n</head>\n\n<body id="page-h'
    'omepage" class="section-homepage">\n    <div class="region region-page-top">\n    \n\n<div id="cern-to'
    'olbar" class="user-not-authenticated">\n  <h1><a href="http://cern.ch" title="CERN">CERN <span>Acceler'
    'ating science</span></a></h1><ul><li class="cern-accountli"><a href="https://home.web.cern.ch/Shibbole'
    'th.sso/?target=https%3A%2F%2Fhome.web.cern.ch%2Fshib_login%2Fnode%2F186" title="Sign in to your CERN a'
    'ccount" class="cern-account">Sign in</a></li><li><a href="http://cern.ch/directory" title="Search CERN'
    ' resources and browse the directory" class="cern-directory">Directory</a></li></ul></div>\n  </div><!-'
    '- /.region -->\n  <!-- PAGE.TPL from CERN Public theme -->\n<div id="bg-img">\n\t<header id="header" r'
    'ole="banner">\n\t\n\t  <h1 id="cern-logo"><a href="/" title="Home" rel="home">CERN</a></h1>\n\t\n\t  '
    '\t  \n\t  <div id="header-content"> \n\t    <div id="nav-bar">  \n\t      \t        <nav id="main-menu'
    '" role="navigation">\n\t          <h2 class="element-invisible">Main menu</h2><ul id="nav" class="menu'
    '"><li class="menu-461 first"><a href="/about">About CERN</a></li>\n<li class="menu-675"><a href="/stud'
    'ents-educators">Students &amp; Educators</a></li>\n<li class="menu-673"><a href="/scientists">Scientis'
    'ts</a></li>\n<li class="menu-674 last"><a href="/cern-people">CERN people</a></li>\n</ul>\t        </n'
    'av>\n\t      \t     \t  <div class="region region-lang-switch">\n    <div id="block-locale-language" c'
    'lass="block block-locale">\n\n      \n  <ul class="language-switcher-locale-url"><li class="en first a'
    'ctive"><a href="/" class="language-link active" xml:lang="en">English</a></li>\n<li class="fr last"><a'
    ' href="/fr" class="language-link" xml:lang="fr">Fran\xc3\xa7ais</a></li>\n</ul>  \n</div>\n  </div><!-'
    '- /.region -->\n\t  \t</div>\n\t  </div>\n\t  \n\t  \t\n\t</header>\n\t\n\t<div id="main" role="main">'
    '\n\t  \t\n\t\t<a id="main-content"></a>\n\t\t\n\t\t\n<!-- node.tpl from cern_public begins -->\n\n\n\n'
    '\n<!-- /node.tpl from cern_public ends -->\n\t\t\n\t\t<div class="update-area">\n\t\t<section id="bloc'
    'k-block-16" class="block block-block">\n\n      \n  <h2>CERN Updates</h2>\n  \n</section>\n<section id'
    '="block-views-4120d3b48fdd2fcc564776112836d0f0" class="block block-views block-updates-standard">\n\n '
    '     \n  <div class="view view-Homepage-updates-blocks view-id-Homepage_updates_blocks view-display-id'
    '-block_updates_standard view-dom-id-dc5ce4f3cf0fea9db970ad5ff27d8cd6">\n        \n  \n  \n      <div c'
    'lass="view-content">\n      <div class="item-list">    <ul>          <li class="views-row views-row-1 '
    'views-row-odd views-row-first"><a href="/about/updates/2015/07/lhc-back-collision-mode">LHC back in co'
    'llision mode</a><span class="field-content">7 July</span>\n</li>\n          <li class="views-row views'
    '-row-2 views-row-even"><a href="/about/updates/2015/07/particular-new-podcast-atlas">In particular: A '
    'new podcast from ATLAS </a><span class="field-content">3 July</span>\n</li>\n          <li class="view'
    's-row views-row-3 views-row-odd views-row-last"><a href="/about/updates/2015/06/chasing-clouds-lhc">Ch'
    'asing clouds in the LHC</a><span class="field-content">25 June</span>\n</li>\n      </ul></div>    </d'
    'iv>\n  \n  \n  \n     \n<div class="more-link">\n  <a href="/about/updates">\n    Past updates  </a>\n'
    '</div>\n\n  \n\n  \n  \n</div>  \n</section>\n<section id="block-search-form" class="block block-searc'
    'h">\n\n      \n  <form class="search-form" role="search" action="/" method="post" id="search-block-for'
    'm" accept-charset="UTF-8"><div><div class="container-inline">\n      <h2 class="element-invisible">Sea'
    'rch form</h2>\n    <div class="form-item form-type-textfield form-item-search-block-form">\n  <label c'
    'lass="element-invisible" for="edit-search-block-form--2">Search this site </label>\n <input title="Ent'
    'er the terms you wish to search for." class="custom-search-box form-text" placeholder="" onblur="if (t'
    'his.value == &#039;&#039;) {this.value = &#039;Search this site&#039;;}" onfocus="if (this.value == &#'
    '039;Search this site&#039;) {this.value = &#039;&#039;;}" type="text" id="edit-search-block-form--2" n'
    'ame="search_block_form" value="Search this site" size="20" maxlength="128" />\n</div>\n<div class="for'
    'm-actions form-wrapper" id="edit-actions"><input type="submit" id="edit-submit" name="op" value="Searc'
    'h" class="form-submit" /></div><input type="hidden" name="form_build_id" value="form-vi_O-0vaFYqtE13Kg'
    'zdPpmUwmpSFygMXPZm4vty7pzE" />\n<input type="hidden" name="form_id" value="search_block_form" />\n</di'
    'v>\n</div></form>  \n</section>\n\t\t\n\t\t</div>\n\t  \n\t</div><!-- /#main -->\n\t\n\t\t\n</div><!--'
    ' /#bg-img -->\n\n<footer id="footer" role="contentinfo">\n  \t  <div class="region region-footer-2">\n'
    '    <div id="block-menu-menu-global-footer-menu-2" class="block block-menu">\n\n        <h2>General in'
    'fo</h2>\n    \n  <ul class="menu"><li class="first leaf"><a href="http://cern.ch/jobs" title="">Jobs</'
    'a></li>\n<li class="leaf"><a href="http://cern.ch/outreach" title="">Visits</a></li>\n<li class="last '
    'leaf"><a href="http://cern.ch/press" title="">Press</a></li>\n</ul>  \n</div>\n  </div><!-- /.region -'
    '->\n  \t  <div class="region region-footer-3">\n    <div id="block-menu-menu-global-footer-menu-3" cla'
    'ss="block block-menu">\n\n        <h2>CERN &amp; you</h2>\n    \n  <ul class="menu"><li class="first l'
    'eaf"><a href="http://cern.ch/procurement" title="">Doing business with CERN</a></li>\n<li class="leaf"'
    '><a href="http://cern.ch/knowledgetransfer" title="">Knowledge transfer</a></li>\n<li class="leaf"><a '
    'href="http://cern.ch/project-voisins/" title="">CERN&#039;s neighbours</a></li>\n<li class="leaf"><a h'
    'ref="http://cern.ch/giving" title="">Giving to CERN</a></li>\n<li class="last leaf"><a href="/partners'
    'hips" title="">Partnerships</a></li>\n</ul>  \n</div>\n  </div><!-- /.region -->\n  \t  <div class="re'
    'gion region-footer-5">\n    <div id="block-block-5" class="block block-block">\n\n        <h2>Contact<'
    '/h2>\n    \n  <p>CERN<br />\nCH-1211 Geneva 23<br />\nSwitzerland</p>\n<p><a href="/contact">How to re'
    'ach us</a></p>\n  \n</div>\n  </div><!-- /.region -->\n\t  <div class="region region-footer-4">\n    <'
    'div id="block-menu-menu-global-footer-menu-5" class="block block-menu">\n\n        <h2>Connect with CE'
    'RN</h2>\n    \n  <ul class="menu"><li class="first leaf"><a href="http://facebook.com/cern" title="">F'
    'acebook</a></li>\n<li class="leaf"><a href="http://twitter.com/cern" title="">Twitter</a></li>\n<li cl'
    'ass="leaf"><a href="http://plus.google.com/+CERN/" title="">Google+</a></li>\n<li class="leaf"><a href'
    '="http://youtube.com/cern" title="">YouTube</a></li>\n<li class="leaf"><a href="http://itunes.apple.co'
    'm/institution/cern-european-organization/id390118692" title="">iTunes U</a></li>\n<li class="last leaf'
    '"><a href="/feeds" title="">Feeds</a></li>\n</ul>  \n</div>\n  </div><!-- /.region -->\n\t  <div class'
    '="region region-footer-1">\n    <div id="block-block-4" class="block block-block">\n\n      \n  <p><a '
    'href="http://cern.ch/copyright">\xc2\xa9 Copyright CERN 2015</a></p>  \n</div>\n  </div><!-- /.region '
    '-->\n</footer>\n\n<!--[if lte IE 8]><img id="bg" src="" /><![endif]-->\n\n  \n  <!--[if (lt IE 9) & (!'
    'IEMobile)]>\n    <script src="/sites/home.web.cern.ch/themes/cern_base/js/ie/imgsizer.js"></script>\n '
    '   <script src="/sites/home.web.cern.ch/themes/cern_base/js/ie/selectivizr-min.js"></script>\n    <scr'
    'ipt src="/sites/home.web.cern.ch/themes/cern_base/js/ie/jquery-extra-selectors.js"></script>\n  <![end'
    'if]-->\n\n  <!-- Prompts all IE6 users to install Google Chromeframe -->\n  <!--[if lt IE 7]>\n   <scr'
    'ipt src="https://ajax.googleapis.com/ajax/libs/chrome-frame/1/CFInstall.min.js"></script>\n   <script>'
    'CFInstall.check();</script>\n  <![endif]-->\n\n  <!--<script src="https://get.gridsetapp.com/125/overl'
    'ay/"></script> -->\n\n</body>\n</html>\n\n\n\n',
    'headers': {
        'Via': '1.1 drupallb01.cern.ch',
        'X-Drupal-Cache': 'HIT',
        'Content-Language': 'en',
        'Transfer-Encoding': 'chunked',
        'Set-Cookie': 'drupallb01_80=.drupal23; path=/;',
        'Expires': 'Sun, 19 Nov 1978 05:00:00 GMT',
        'Vary': 'Cookie,Accept-Encoding',
        'Server': 'Apache',
        'Last-Modified': 'Mon, 13 Jul 2015 13:40:29 GMT',
        'Connection': 'close',
        'Etag': '"1436794829-0"',
        'Link': '<http://home.web.cern.ch/>; rel="canonical",<http://home.web.cern.ch/node/186>; rel="shortlink"',
        'Cache-Control': 'public, max-age=60',
        'Date': 'Mon, 13 Jul 2015 14:03:17 GMT',
        'Content-Type': 'text/html; charset=utf-8',
        'X-Generator': 'Drupal 7 (http://drupal.org)'
    },
}

vinput = """
{
    "http://m.cern.ch": [
        {
            "type": "ws",
            "app": "IIS",
            "ver": "7.5"
        },
        {
            "type": "os",
            "app": "Windows Server",
            "ver": null
        },
        {
            "type": "web-frameworks",
            "app": "Microsoft ASP.NET",
            "ver": null
        }
    ],
    "http://m.cern.ch/sub": [
        {
            "type": "os",
            "app": "Windows Server",
            "ver": null
        },
        {
            "type": "web-frameworks",
            "app": "Microsoft ASP.NET",
            "ver": null
        },
        {
            "type": "javascript-frameworks",
            "app": "jQuery",
            "ver": null
        },
        {
            "type": "ws",
            "app": "IIS",
            "ver": "7"
        }
    ]
}
"""

voutput = """
{
    "http://m.cern.ch": [
        {
            "type": "ws",
            "app": "IIS",
            "ver": "7.5"
        },
        {
            "type": "os",
            "app": "Windows Server",
            "ver": null
        },
        {
            "type": "web-frameworks",
            "app": "Microsoft ASP.NET",
            "ver": null
        }
    ],
    "http://m.cern.ch/sub": [
        {
            "type": "javascript-frameworks",
            "app": "jQuery",
            "ver": null
        },
        {
            "type": "ws",
            "app": "IIS",
            "ver": "7"
        }
    ]
}
"""
